==> haskell-hls-explicit-imports-plugin-1.2.1.0-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-imports-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-explicit-imports-plugin
version:              1.2.1.0
visibility:           public
id:                   hls-explicit-imports-plugin-1.2.1.0-6YmIe7wZTpwTKMKd6cKC7
key:                  hls-explicit-imports-plugin-1.2.1.0-6YmIe7wZTpwTKMKd6cKC7
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Explicit imports plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  62dbc0add24ef095c98f0d478bfdccfc
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitImports
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-explicit-imports-plugin-1.2.1.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-explicit-imports-plugin-1.2.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-imports-plugin
hs-libraries:         HShls-explicit-imports-plugin-1.2.1.0-6YmIe7wZTpwTKMKd6cKC7
depends:
    aeson-2.1.2.1-GLiPeiAR7ZSFwx9H49aVEA base-4.16.4.0
    containers-0.6.5.1 deepseq-1.4.6.1 ghc-9.2.8
    ghcide-1.10.0.0-C4QP9CvVIM076nXC3eqO6Z
    hls-graph-1.9.0.0-Ln446eHMli3Jn8E5Sosqko
    hls-plugin-api-1.6.0.0-6aAt33ROEfGFGKmYzVIAEM
    lsp-1.6.0.0-CTr572FCQofGXaNrrF5WCB text-1.2.5.0
    unordered-containers-0.2.20-4Y4A6Wn35BzvWquDAxs4Y

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-imports-plugin/html/hls-explicit-imports-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-imports-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-explicit-imports-plugin-1.2.1.0-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-imports-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-explicit-imports-plugin
version:              1.2.1.0
visibility:           public
id:                   hls-explicit-imports-plugin-1.2.1.0-GmZYB4w3vFqFGeSSoVLUK7
key:                  hls-explicit-imports-plugin-1.2.1.0-GmZYB4w3vFqFGeSSoVLUK7
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Explicit imports plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  86443973897ad3400a97d2d3d5867dff
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitImports
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-explicit-imports-plugin-1.2.1.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-explicit-imports-plugin-1.2.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-imports-plugin
hs-libraries:
    HShls-explicit-imports-plugin-1.2.1.0-GmZYB4w3vFqFGeSSoVLUK7

depends:
    aeson-2.1.2.1-GLiPeiAR7ZSFwx9H49aVEA base-4.16.4.0
    containers-0.6.5.1 deepseq-1.4.6.1 ghc-9.2.8
    ghcide-1.10.0.0-1EmRaN29zOy1WiehU7ggQ6
    hls-graph-1.9.0.0-7QqrPUyZ0uJayRug0DY5p
    hls-plugin-api-1.6.0.0-2DR4541DY8a7Qydm6Fs7pB
    lsp-1.6.0.0-CTr572FCQofGXaNrrF5WCB text-1.2.5.0
    unordered-containers-0.2.20-4Y4A6Wn35BzvWquDAxs4Y

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-imports-plugin/html/hls-explicit-imports-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-imports-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
